@@ -1,15 +1,10 @@
 """
-________________________________
-|                              |
-| pyserved                     |
-|                              |
-| Only works with utf-8        | 
-| files. (for now.)            |
-|                              | 
-| By:                          |
-| Shaurya Pratap Singh         |
-| 2021 ©                       |
-|______________________________|
+File:pdlisten.py
+
+Q.  Does what?
+A.  This program is used to listen for incoming connections from the 
+    pdsnd.py program. If it recieves a connection, it will write the
+    file in the directory. 
 """
 
 import sys
@@ -123,6 +118,6 @@ except KeyboardInterrupt:
     print("\n[bold red]KeyboardInterrupt[/]")
     exit()
 except Exception as e:
-    print(f"\n[bold red] {repr(e)} \n\n If the problem presists, contact the owner of the package at https://github.com/SblipDev/pyserved[/] \n")
+    print(f"\n[bold red] {repr(e)} \n\n If the problem persists, contact the owner of the package at https://github.com/SblipDev/pyserved[/] \n")
     exit()
     
